**To delete an input**

The following ``delete-input`` example deletes the specified input. ::

    aws iotevents delete-input \
        --input-name PressureInput

This command produces no output.

For more information, see `DeleteInput <https://docs.aws.amazon.com/iotevents/latest/apireference/API_DeleteInput>`__ in the *AWS IoT Events API Reference*.
